# owner
Tools to prove ownerhip of content


To install:	```pip install owner```


# Examples

```python
from owner import weave, unweave

assert (weave(b'bob and alice') == 
        (b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00'
         b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00'
         b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00`\x0c14\xf2\x834\xa3\xc0\x0c\xe3\xa8i9\r'
         b'\xe2\xd3\x01\xb1Fj\x11U\x92j^Z\xa8\xaa\x9e\x89\xa2\xd5bob and alice')
       )

unweave(weave(b'bob and alice')) == b'bob and alice'
```

Some utils...

```python
from owner import bytes_to_hash, bytes_to_int, 

assert (bytes_to_hash(b'bob and alice') 
        == b'\x0c14\xf2\x834\xa3\xc0\x0c\xe3\xa8i9\r\xe2\xd3\x01\xb1Fj\x11U\x92j^Z\xa8\xaa\x9e\x89\xa2\xd5')

assert bytes_to_int(int_to_bytes(123456)) == 123456
```